diff roundup/roundupdb.py @ 3904:91008ec8f9a0

retire "topic" usage "Topic" still appears in the locale files. I'm sure we need to support that for existing trackers. I *think* they don't care about any of the other changes that have been made. I also left Ka-Ping Yee's original design document unchanged. This takes care of sf feature request [SF#953161]
author Justus Pendleton <jpend@users.sourceforge.net>
date Sun, 16 Sep 2007 02:45:11 +0000
parents f762fa13cd8d
children 63ab356dfcf9
line wrap: on
line diff
--- a/roundup/roundupdb.py	Fri Sep 14 15:55:25 2007 +0000
+++ b/roundup/roundupdb.py	Sun Sep 16 02:45:11 2007 +0000
@@ -16,7 +16,7 @@
 # BASIS, AND THERE IS NO OBLIGATION WHATSOEVER TO PROVIDE MAINTENANCE,
 # SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 #
-# $Id: roundupdb.py,v 1.132 2007-09-10 19:18:31 forsberg Exp $
+# $Id: roundupdb.py,v 1.133 2007-09-16 02:45:11 jpend Exp $
 
 """Extending hyperdb with types specific to issue-tracking.
 """
@@ -142,10 +142,10 @@
     #
     # Note that this list also includes properties
     # defined in the classic template:
     # assignedto, topic, priority, status.
     (
         ''"title", ''"messages", ''"files", ''"nosy", ''"superseder",
-        ''"assignedto", ''"topic", ''"priority", ''"status",
+        ''"assignedto", ''"keyword", ''"priority", ''"status",
         # following properties are common for all hyperdb classes
         # they are listed here to keep things in one place
         ''"actor", ''"activity", ''"creator", ''"creation",
@@ -142,10 +142,10 @@
     # Note that this list also includes properties
     # defined in the classic template:
-    # assignedto, topic, priority, status.
+    # assignedto, keyword, priority, status.
     (
         ''"title", ''"messages", ''"files", ''"nosy", ''"superseder",

Roundup Issue Tracker: http://roundup-tracker.org/